==> pui-react-autocomplete-2.0.0.tgz: package/README.md <==
# pui-react-autocomplete

React autocomplete component

Pivotal UI React ([GitHub](https://github.com/pivotal-cf/pivotal-ui-react), [npm](https://www.npmjs.com/browse/keyword/pivotal%20ui%20modularized)) is a collection of [React](https://facebook.github.io/react/) components for rapidly building and prototyping UIs.

This component requires React v0.13

See the [Pivotal UI Styleguide](http://styleguide.pivotal.io/react.html#autocomplete_react) for fully rendered examples.

## Components

### Autocomplete

An autocomplete that comes with a dropdown list

```js
var Autocomplete = require('pui-react-autocomplete').Autocomplete;
var initialItems = ['Pivotal Labs', 'Cloud Foundry', 'Data Services'];
var onInitializeItems = function(callback) { callback(initialItems) };
var onPick = function(value) { console.log(value); };
var MyComponent = React.createClass({
  render() {
    return <Autocomplete {onInitializeItems, onPick}/>
  }
});
```

#### Properties

- `disabled`
  - `Bool`: Greys out and turns off event handlers.

- `input`
  - `React Component`: Use if you want to override the default AutocompleteInput.

- `maxItems`
  - `Number`: Cap the number of items that can appear in the dropdown list.

- `onClick`
  - `Function`: Event handler for click on the input (e.g. to automatically select value text).

- `onFilter`
  - `Function`: Optionally filter list items (other than by the input value).

- `onFocus`
  - `Function`: Event handler for focus on the input (e.g. to automatically show the list).

- `onInitializeItems`
  - `Function`: Your one chance to populate the list.

- `onPick`
  - `Function`: Event handler for choosing an item in the list.

- `onSearch`
  - `Function`: Override default search algorithm called whenever input value changes.

- `placeholder`
  - `String`: Placeholder text for the input.

- `selectedSuggestion`
  - `Any`: Matcher for the item in the list that is currently selected.

- `value`
  - `String`: The value of the input.


*****************************************

(c) Copyright 2015 Pivotal Software, Inc. All Rights Reserved.

==> pui-react-autocomplete-6.2.1.tgz: package/README.md <==
# pui-react-autocomplete

React autocomplete component

Pivotal UI React ([GitHub](https://github.com/pivotal-cf/pivotal-ui-react), [npm](https://www.npmjs.com/browse/keyword/pivotal%20ui%20modularized)) is a collection of [React](https://facebook.github.io/react/) components for rapidly building and prototyping UIs.

This component requires React v0.13

See the [Pivotal UI Styleguide](http://styleguide.pivotal.io/react.html#autocomplete_react) for fully rendered examples.

## Components

### Autocomplete

An autocomplete that comes with a dropdown list

```js
var Autocomplete = require('

#### Properties

- `disabled`
  - `Bool`: Greys out and turns off event handlers.

- `input`
  - `React Component`: Use if you want to override the default AutocompleteInput.

- `maxItems`
  - `Number`: Cap the number of items that can appear in the dropdown list.

- `onClick`
  - `Function`: Event handler for click on the input (e.g. to automatically select value text).

- `onFilter`
  - `Function`: Optionally filter list items (other than by the input value).

- `onFocus`
  - `Function`: Event handler for focus on the input (e.g. to automatically show the list).

- `onInitializeItems`
  - `Function`: Your one chance to populate the list.

- `onPick`
  - `Function`: Event handler for choosing an item in the list.

- `onSearch`
  - `Function`: Override default search algorithm called whenever input value changes.

- `placeholder`
  - `String`: Placeholder text for the input.

- `selectedSuggestion`
  - `Any`: Matcher for the item in the list that is currently selected.

- `value`
  - `String`: The value of the input.


*****************************************

(c) Copyright 2015 Pivotal Software, Inc. All Rights Reserved.
